==> aws-cdk-scala_3-0.14.0-sources.jar: io/burkard/cdk/services/msk/CfnCluster.scala <==
package io.burkard.cdk.services.msk

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCluster {

  def apply(
    internalResourceId: String,
    kafkaVersion: String,
    brokerNodeGroupInfo: software.amazon.awscdk.services.msk.CfnCluster.BrokerNodeGroupInfoProperty,
    numberOfBrokerNodes: Number,
    clusterName: String,
    configurationInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.ConfigurationInfoProperty] = None,
    tags: Option[AnyRef] = None,
    enhancedMonitoring: Option[String] = None,
    clientAuthentication: Option[software.amazon.awscdk.services.msk.CfnCluster.ClientAuthenticationProperty] = None,
    openMonitoring: Option[software.amazon.awscdk.services.msk.CfnCluster.OpenMonitoringProperty] = None,
    encryptionInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.EncryptionInfoProperty] = None,
    loggingInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.LoggingInfoProperty] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.msk.CfnCluster =
    software.amazon.awscdk.services.msk.CfnCluster.Builder
      .create(stackCtx, internalResourceId)
      .kafkaVersion(kafkaVersion)
      .brokerNodeGroupInfo(brokerNodeGroupInfo)
      .numberOfBrokerNodes(numberOfBrokerNodes)
      .clusterName(clusterName)
      .configurationInfo(configurationInfo.orNull)
      .tags(tags.orNull)
      .enhancedMonitoring(enhancedMonitoring.orNull)
      .clientAuthentication(clientAuthentication.orNull)
      .openMonitoring(openMonitoring.orNull)
      .encryptionInfo(encryptionInfo.orNull)
      .loggingInfo(loggingInfo.orNull)
      .build()
}

==> aws-cdk-scala_3-0.22.0-sources.jar: io/burkard/cdk/services/msk/CfnCluster.scala <==
package io.burkard.cdk.services.msk

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCluster {

  def apply(
    internalResourceId: String,
    kafkaVersion: String,
    brokerNodeGroupInfo: software.amazon.awscdk.services.msk.CfnCluster.BrokerNodeGroupInfoProperty,
    numberOfBrokerNodes: Number,
    clusterName: String,
    configurationInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.ConfigurationInfoProperty] = None,
    tags: Option[Map[String, String]] = None,
    enhancedMonitoring: Option[String] = None,
    clientAuthentication: Option[software.amazon.awscdk.services.msk.CfnCluster.ClientAuthenticationProperty] = None,
    openMonitoring: Option[software.amazon.awscdk.services.msk.CfnCluster.OpenMonitoringProperty] = None,
    encryptionInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.EncryptionInfoProperty] = None,
    currentVersion: Option[String] = None,
    loggingInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.LoggingInfoProperty] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.msk.CfnCluster =
    software.amazon.awscdk.services.msk.CfnCluster.Builder
      .create(stackCtx, internalResourceId)
      .kafkaVersion(kafkaVersion)
      .brokerNodeGroupInfo(brokerNodeGroupInfo)
      .numberOfBrokerNodes(numberOfBrokerNodes)
      .clusterName(clusterName)
      .configurationInfo(configurationInfo.orNull)
      .tags(tags.map(_.asJava).orNull)
      .enhancedMonitoring(enhancedMonitoring.orNull)
      .clientAuthentication(clientAuthentication.orNull)
      .openMonitoring(openMonitoring.orNull)
      .encryptionInfo(encryptionInfo.orNull)
      .currentVersion(currentVersion.orNull)
      .loggingInfo(loggingInfo.orNull)
      .build()
}
